
from distutils.core import setup
setup(
     name        =  "Terra_PrintAll",
     version     =  "1.2.0",
     py_modules  =  ["Terra_PrintAll"],
     author      =  "TerraJuly",
     author_email =  "caijie_hui@163.com",
     url         ="http://www.terra.com",
     description="Upgrade from 1.1.0",
     )



""""This is the print_all function """
def print_all(one_list,level):
    for each_item in one_list:
        if isinstance(each_item,list):
             print_all(each_item,level+1)
        else:
            for count in range(level):
                     print("\t",end="")
            print(each_item)

            
